@@ -1,10 +1,10 @@
 import sys
 import requests
 
-from kraken_thing.libraries import json_xp as json
-from kraken_thing.libraries.class_small_db import Small_db 
+from .libraries import json_xp as json
+from .libraries.class_small_db import Small_db 
 
-from kraken_thing.kraken_class_thing import Thing
+from .kraken_class_thing import Thing
 
 
 
